@@ -184,7 +184,9 @@ module StateMachines
     # == Observers
     #
     # In order to hook in observer support for your application, the
-    # ActiveModel::Observing feature must be included.  Because of the way
+    # ActiveModel::Observing feature must be included.  This can be added by including the
+    # https://github.com/state-machines/state_machines-activemodel-observers gem in your 
+    # Gemfile. Because of the way
     # ActiveModel observers are designed, there is less flexibility around the
     # specific transitions that can be hooked in.  However, a large number of
     # hooks *are* supported.  For example, if a transition for a object's
@@ -380,7 +382,7 @@ module StateMachines
           end
 
           default_options = default_error_message_options(object, attribute, message)
-          object.errors.add(attribute, message, options.merge(default_options))
+          object.errors.add(attribute, message, **options, **default_options)
         end
       end
 
@@ -405,6 +407,10 @@ module StateMachines
       def define_state_initializer
         define_helper :instance, <<-end_eval, __FILE__, __LINE__ + 1
           def initialize(params = {})
+            params.transform_keys! do |key|
+              self.class.attribute_aliases[key.to_s] || key.to_s
+            end if self.class.respond_to?(:attribute_aliases)
+
             self.class.state_machines.initialize_states(self, {}, params) { super }
           end
         end_eval
